# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .balancer import *
from .deployment import *
from .listener import *
from .routing_rule import *
from .target import *
from .target_set import *
from ._inputs import *
from . import outputs

def _register_module():
    import pulumi
    from .. import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "spotinst:multai/balancer:Balancer":
                return Balancer(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "spotinst:multai/deployment:Deployment":
                return Deployment(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "spotinst:multai/listener:Listener":
                return Listener(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "spotinst:multai/routingRule:RoutingRule":
                return RoutingRule(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "spotinst:multai/target:Target":
                return Target(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "spotinst:multai/targetSet:TargetSet":
                return TargetSet(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("spotinst", "multai/balancer", _module_instance)
    pulumi.runtime.register_resource_module("spotinst", "multai/deployment", _module_instance)
    pulumi.runtime.register_resource_module("spotinst", "multai/listener", _module_instance)
    pulumi.runtime.register_resource_module("spotinst", "multai/routingRule", _module_instance)
    pulumi.runtime.register_resource_module("spotinst", "multai/target", _module_instance)
    pulumi.runtime.register_resource_module("spotinst", "multai/targetSet", _module_instance)

_register_module()
